---
meta:
    title: Spacing Tokens
    description: Spacing tokens are used to provide consistent spacing between content in your app.
---

# Spacing Tokens

Spacing tokens are used to provide consistent spacing between content in your app.

| Token                      | Value          | Example                                                                                                               |
| -------------------------- | -------------- | --------------------------------------------------------------------------------------------------------------------- |
| `--terra-spacing-3x-small` | 0.125rem (2px) | <div class="spacing-demo" style="width: var(--terra-spacing-3x-small); height: var(--terra-spacing-3x-small);"></div> |
| `--terra-spacing-2x-small` | 0.25rem (4px)  | <div class="spacing-demo" style="width: var(--terra-spacing-2x-small); height: var(--terra-spacing-2x-small);"></div> |
| `--terra-spacing-x-small`  | 0.5rem (8px)   | <div class="spacing-demo" style="width: var(--terra-spacing-x-small); height: var(--terra-spacing-x-small);"></div>   |
| `--terra-spacing-small`    | 0.75rem (12px) | <div class="spacing-demo" style="width: var(--terra-spacing-small); height: var(--terra-spacing-small);"></div>       |
| `--terra-spacing-medium`   | 1rem (16px)    | <div class="spacing-demo" style="width: var(--terra-spacing-medium); height: var(--terra-spacing-medium);"></div>     |
| `--terra-spacing-large`    | 1.25rem (20px) | <div class="spacing-demo" style="width: var(--terra-spacing-large); height: var(--terra-spacing-large);"></div>       |
| `--terra-spacing-x-large`  | 1.75rem (28px) | <div class="spacing-demo" style="width: var(--terra-spacing-x-large); height: var(--terra-spacing-x-large);"></div>   |
| `--terra-spacing-2x-large` | 2.25rem (36px) | <div class="spacing-demo" style="width: var(--terra-spacing-2x-large); height: var(--terra-spacing-2x-large);"></div> |
| `--terra-spacing-3x-large` | 3rem (48px)    | <div class="spacing-demo" style="width: var(--terra-spacing-3x-large); height: var(--terra-spacing-3x-large);"></div> |
| `--terra-spacing-4x-large` | 4.5rem (72px)  | <div class="spacing-demo" style="width: var(--terra-spacing-4x-large); height: var(--terra-spacing-4x-large);"></div> |
